pdf多路召回
https://github.com/PaddlePaddle/PaddleNLP/blob/develop/pipelines/examples/chatbot/chat_pdf_multi_recall_example.py
https://github.com/freedmand/semantra

开源列表
https://github.com/eugeneyan/open-llms

AI智能文章批量生成器
https://ai.de1919.com/
https://blog.csdn.net/weixin_45788869/article/details/130319005?csdn_share_tail=%7B%22type%22%3A%22blog%22%2C%22rType%22%3A%22article%22%2C%22rId%22%3A%22130319005%22%2C%22source%22%3A%22unlogin%22%7D

增加bloom
https://github.com/huggingface/transformers-bloom-inference
https://huggingface.co/bigscience/bloom-560m


提示模板
https://github.com/f/awesome-chatgpt-prompts
https://github.com/TheRamU/Fay


# 赚钱
https://github.com/xiaoming2028/Chatgpt-Makes-Money

#
https://github.com/yuanzhoulvpi2017/zero_nlp

# chatSQL
https://huggingface.co/spaces/ls291/ChatSQL

# 网盘
https://github.com/sc0tfree/updog

# 模型加速
https://mp.weixin.qq.com/s/uV4Y_q4GnTUAsRVHxJGxGA

# embedding: https://huggingface.co/spaces/mteb/leaderboard
https://instructor-embedding.github.io/
https://modelscope.cn/models/damo/nlp_corom_sentence-embedding_chinese-base/summary
https://github.com/JovenChu/embedding_model_test

打榜
https://aistudio.baidu.com/aistudio/competition/detail/45/0/leaderboard

# 长篇小说
https://www.jiqizhixin.com/articles/2023-05-28-3


https://github.com/zwq2018/Data-Copilot
https://www.qbitai.com/2023/07/66313.html  就是这个新闻。Data-copilo


https://github.com/zilliztech/akcio/blob/a48121d8fb93765ed7cc2de28de29ad5504ae117/src_langchain/llm/ernie.py#L54


https://huggingface.co/arkii/chatglm2-6b-ggml/blob/main/chatglm_langchain.py
